%%%% Anne Collins
%%%% LNCC, Brown University
%%%% 2012
%%%% Psych-review supplementary material
%%%% Cognitive control over learning: Creating, clustering and generalizing
%%%% Task-set structure


%%%% script to simulate main paper results




%% task1: 16 contexts --> 2TS

clear all

nrep = 50;
taskNumber = 1;

param1 = [2 30 1 1 0 0 1 1 0];% alpha, beta, tau, b0(1,3), init, inits, eps
param2 = [1000 30 1 1 0 0 1 1 0];% alpha, beta, tau, b0(1,3), init, inits, eps


for rep = 1:nrep
    input = createTask(taskNumber);
    data = CTS(param1,input);
    for c = 1:16
        Cor(c,:) = data.corseq(data.Cseq == c);
    end
    C1(rep,:) = mean(Cor);
    N1(rep) = data.N;
    data = CTS(param2,input);
    for c = 1:16
        Cor(c,:) = data.corseq(data.Cseq == c);
    end
    C2(rep,:) = mean(Cor);
    N2(rep) = data.N;
end

figure
subplot(1,2,1)
errorbar(mean(C1),std(C1)/sqrt(rep),'k')
hold on
errorbar(mean(C2),std(C2)/sqrt(rep),'r')
plot(0*mean(C1)+(1/6),'color',[.5 .5 .5])
hold off
title('Initial perf improvement')
legend({'\alpha = 2','\alpha = 1000','chance level'})
axis([0,20,0,1])
xlabel('trials per context')
ylabel('Proportion correct')
subplot(1,2,2)
bar([1 2],[mean(N1) mean(N2)],'facecolor',[1 1 1])
hold on
errorbar(1,mean(N1),std(N1)/sqrt(rep),'k')
errorbar(2,mean(N2),std(N2)/sqrt(rep),'r')
hold off
set(gca,'xtick',[1 2],'xticklabel',{'\alpha = 2','\alpha = 1000'})
ylabel('Number of TS')



%% task1: correct expert selection



clear all

nrep = 50;
taskNumber = 1;

param = [2 30 1 1/3 1/3 1/3 1 1 0];% alpha, beta, tau, b0(1,3), init, inits, eps

for rep = 1:nrep
    input = createTask(taskNumber);
    data = CTS(param,input);
    B1(rep,:) = data.bseq(1,:);
    B2(rep,:) = data.bseq(2,:);
    B3(rep,:) = 1-B1(rep,:)-B2(rep,:);
end

figure
errorbar(mean(B1),std(B1)/sqrt(rep),'b')
hold on
errorbar(mean(B2),std(B2)/sqrt(rep),'c')
errorbar(mean(B3),std(B3)/sqrt(rep),'k')
hold off
title('Context identification')
legend({'C-TS','S-TS','flat'})
ylabel('Experts weights')
xlabel('Trial number')

%% task2: experiment task

clear all

nrep = 200;
taskNumber = 2;

%alpha, beta, tau, b0(1,3), init, inits, eps
param{1} = [2 30 1 1 0 0 1 1 0];% C-expert
param{2} = [2 30 1 0 1 0 1 1 0];% S-expert
param{3} = [2 30 1 0 0 1 1 1 0];% flat
param{4} = [2 30 1 1/3 1/3 1/3 1 1 0];% hybrid

Name = {'C-TS','S-TS','Flat','Hybrid'};
for model = 1:4

for rep = 1:nrep
    input = createTask(taskNumber);
    data = CTS(param{model},input);
    H = data.Code == input.HAseq;
    L = data.Code == input.LAseq;
        
    C3(rep,:) = .5*data.corseq(data.Cseq ==3 & data.Sseq == 1) + ...
        .5*data.corseq(data.Cseq ==3 & data.Sseq == 2);
    C4(rep,:) = .5*data.corseq(data.Cseq ==4 & data.Sseq == 1) + ...
        .5*data.corseq(data.Cseq ==4 & data.Sseq == 2);
    H3(rep,:) = .5*H(data.Cseq ==3 & data.Sseq == 1) + ...
        .5*H(data.Cseq ==3 & data.Sseq == 2);
    H4(rep,:) = .5*H(data.Cseq ==4 & data.Sseq == 1) + ...
        .5*H(data.Cseq ==4 & data.Sseq == 2);
    L3(rep,:) = .5*L(data.Cseq ==3 & data.Sseq == 1) + ...
        .5*L(data.Cseq ==3 & data.Sseq == 2);
    L4(rep,:) = .5*L(data.Cseq ==4 & data.Sseq == 1) + ...
        .5*L(data.Cseq ==4 & data.Sseq == 2);
    
end

E3 = [mean(H3(:,1:5),2) mean(L3(:,1:5),2) mean(C3(:,1:5),2)];
E3(:,end) = 1 -sum(E3,2);
E4 = [mean(H4(:,1:5),2) mean(L4(:,1:5),2) mean(C4(:,1:5),2)];
E4(:,end) = 1 -sum(E4,2);

figure
subplot(1,2,1)
errorbar(mean(C3),std(C3)/sqrt(rep),'b')
hold on
errorbar(mean(C4),std(C4)/sqrt(rep),'g')
hold off
title([Name{model},': Test phase correct'])
legend({'Old TS','new TS'})
axis([0,20,0,1])
xlabel('trials per input pattern')
ylabel('Proportion correct')
subplot(1,2,2)
errorbar(mean(E3),std(E3)/sqrt(rep),'b')
hold on
errorbar(mean(E4),std(E4)/sqrt(rep),'g')
hold off
title([Name{model},': Test phase errors'])
legend({'Old TS','new TS'})
axis([0,4,0,.25])
xlabel('error types')
ylabel('Proportion trials')
set(gca,'xtick',[1:3],'xticklabel',{'NH','NL','NA'})

end
